asr.test.acceptance.test\_relax
===============================

.. automodule:: asr.test.acceptance.test_relax

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_relax_fe_gpaw
   
   

   
   
   

   
   
   